
const {VueLoaderPlugin} = require('vue-loader')
const path = require('path'); //node内置path模块，该模块主要集成文件系统路径操作API
const htmlWebpackPlugin = require('html-webpack-plugin')
function resolve(dir){
    return path.join(__dirname, dir)
}

const config = {
    mode: 'development', //webpack的打包模式
    entry: { //js的入口文件，支持多入口
        // main: path.resolve(__dirname, "../src/index.js"),
        tree: path.resolve(__dirname, '../src/component/tree/tree.js')
    },
    output: { //js打包压缩后的出口文件，多入口时对应的配置应对应变化
        // path: path.resolve(__dirname, '../dist'),
        // filename: 'build.js'
        path: path.resolve(__dirname, '../dist'),
        publicPath: '/dist',
        filename: 'vue-tree.js',
        library: 'Tree',
        libraryTarget: 'umd',
        umdNamedDefine: true
    },
    module: {
         //配置loder使用的规则、作用范围、控制输出的名称、位置；主要用于编译、解释文件
        rules: [{
            test: /\.vue$/, //vue文件加载器
            use: ['vue-loader']
        }, {
            test: /\.js$/,
            use: ['babel-loader'],
            exclude: /node-modules/
        }, {
            test: /.css$/, //css文件加载器
            loaders: ['style-loader', 'css-loader']
        }, {
            test: /.less$/,
            loaders: ['style-loader', 'css-loader', 'less-loader']
        }]
    },
    plugins: [
        //添加VueLoaderPlugin 以响应vue-loader
        new VueLoaderPlugin(),
        new htmlWebpackPlugin({
            filename: 'index.html',
            template: 'src/index.html',
            inject: 'body'
        })
    ],
    resolve: {
        extensions: ['.js', '.vue', '.json', '.css'],
        alias: {
            'vue$': 'vue/dist/vue.esm.js',
            '@': resolve('../src')
        }
    },
};
module.exports = config;